@@ -16,13 +16,16 @@ function (x) {
 
 `cry` <-
 function(Call = NA, Message, ..., warn = FALSE, domain = paste0("R-", .packageName)) {
-	if (is.character(Call))
-		Call <- call(Call[1L], sys.call(-1L)[[1L]]) else
-		if(!is.call(Call)) Call <- sys.call(-1L)
+	if (is.character(Call)) {
+		Call <- call(Call[1L], sys.call(-1L)[[1L]])
+	} else if(is.numeric(Call)) {
+		Call <- sys.call(Call - 1L)
+	} else if(!is.call(Call)) Call <- sys.call(-1L)
 	if(warn) warning(simpleWarning(gettextf(Message, ..., domain = domain), Call)) else
 		stop(simpleError(gettextf(Message, ..., domain = domain), Call))
 }
 
+
 `getElement` <- function (object, name) {
     if (isS4(object))
 		if (.hasSlot(object, name)) slot(object, name) else NULL
